# Taleez Connector
> ATS recruitment management software, manage all your processes from A to Z and centralize all your recruitments: centralization, multi-distribution, career site, CV library...

🔗 https://taleez.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |